package com.gic.finance.web.utils;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.exception.CommonException;

import java.util.List;
/**
 * controller统一返回结果
 * @ClassName: ResultControllerUtils 
 * @Description:  
 * @author guojuxing 
 * @date 2019/8/27 10:14 AM 
 */
public class ResultControllerUtils {

    /**
     * 返回分页正确结果
     * @Title: commonResultPage 
     * @Description:
      * @author guojuxing
     * @param response 
     * @return  java.lang.Object 
      */
    public static Page commonResultPage(ServiceResponse response, Class<?> clazz) {
        if (response.isSuccess()) {
            Page page = (Page) response.getResult();
            page.setResult(EntityUtil.changeEntityListNew(clazz, page.getResult()));
            return page;
        } else {
            throw new CommonException(response);
        }
    }

    /**
     * 统一返回成功结果（分页DTO转为VO）
     * @Title: commonResultOfListVO 
     * @Description:
      * @author guojuxing
     * @param response
     * @param clazz 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    public static RestResponse commonPageResult(ServiceResponse response, Class<?> clazz) {
        if (response.isSuccess()) {
            Page page = (Page) response.getResult();
            page.setResult(EntityUtil.changeEntityListNew(clazz, page.getResult()));
            return RestResponse.success(page);
        } else {
            return RestResponse.failure(response.getCode(), response.getMessage());
        }
    }

    /**
     * 统一返回成功结果（DTO转为VO）
     * @Title: commonResultOfListVO 
     * @Description:
      * @author guojuxing
     * @param response
     * @param clazz 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
      */
    public static RestResponse commonResult(ServiceResponse response, Class<?> clazz) {
        if (response.isSuccess()) {
            return RestResponse.success(EntityUtil.changeEntityListNew(clazz, (List<?>) response.getResult()));
        } else {
            return RestResponse.failure(response.getCode(), response.getMessage());
        }
    }

    /**
     * 返回正确结果
     * @Title: commonResultObject 
     * @Description:
      * @author guojuxing
     * @param response 
     * @return  java.lang.Object 
      */
    public static Object commonResultObject(ServiceResponse response) {
        if (response.isSuccess()) {
            return response.getResult();
        } else {
            throw new CommonException(response);
        }
    }

    /**
     * 返回分页正确结果
     * @Title: commonResultPage 
     * @Description:
      * @author guojuxing
     * @param response 
     * @return  java.lang.Object 
      */
    public static Page commonResultPage(ServiceResponse response) {
        if (response.isSuccess()) {
            return (Page) response.getResult();
        } else {
            throw new CommonException(response);
        }
    }

    /**
     * 统一返回成功结果
     * @Title: commonResult 
     * @Description:
      * @author guojuxing
     * @param response 
     * @return  java.lang.Object 
      */
    public static RestResponse commonResult(ServiceResponse response) {
        if (response.isSuccess()) {
            return RestResponse.success(response.getResult());
        } else {
            return RestResponse.failure(response.getCode(), response.getMessage());
        }
    }
}
